package com.ticketSystem;

import java.util.ArrayList;

/**
 * This class is about each Airplane.
 * every airplane has a type and chairs in general, and belongs to a airline.
 * We have 2 kind of list:
 * -allChairs: this list shows all chairs of this airplane, no matter it is reserved or not.
 * -freeChairs: this list shows chairs which they're not reserved and available.
 *
 * @author Soroush Mehraban
 * @version 1.0.0
 */
public class Airplane {
    private ArrayList<Chair> freeChairs;
    private ArrayList<Chair> allChairs;
    private String type;
    private String airline;

    /**
     * Constructor of this class.
     *it creates an empty airplane without any chair and we've just it's type.
     *
     * @param type type of airplane as String.
     */
    public Airplane(String type, String airline){
        this.type = type;
        this.airline = airline;
        allChairs = new ArrayList<Chair>();
        freeChairs = new ArrayList<Chair>();
    }

    /**
     * this method add a chair to this airplane.
     * at first it is in both lists.
     *
     * @param chair the chair we want to add.
     */
    public void addChair(Chair chair){
        allChairs.add(chair);
        freeChairs.add(chair);
    }

    /**
     * this method gives us list of all chairs, no matter if they're reserved or not.
     *
     * @return allChairs Arraylist.
     */
    public ArrayList<Chair> getAllChairs(){
        return allChairs;
    }

    /**
     * this method gives us list of chairs which they're available and ready to be reserved.
     * if anyone wants reserve a chair, simply remove that chair from this list which is giving to.
     *
     * @return freeChairs ArrayList.
     */
    public ArrayList<Chair> getFreeChairs() {
        return freeChairs;
    }

    /**
     * Getting type of this Airplane.
     *
     * @return type as a String.
     */
    public String getType() {
        return type;
    }

    /**
     * Getting airline which airplane belongs to.
     *
     * @return airline as Stirng.
     */
    public String getAirline() {
        return airline;
    }
}
