package com.ticketSystem;


import java.util.ArrayList;

/**
 * This class is about customer who wants to reserve a flight and own a ticket.
 * it has 6 fields:
 * -firstname: first name of customer
 * -lastname: last name of customer
 * -ID: ID of customer
 * -tickets: a list of tickets that customer booked.
 * -userflights: flights which user added to his/her flights.
 * -airline: airline which has available flights.
 *
 * @author Soroush Mehraban
 * @version 1.0.0
 */
public class Customer {
    private String firstName;
    private String lastName;
    private int ID;
    private ArrayList<Ticket> tickets;
    private ArrayList<Flight> userFlights;
    private Airline airline;

    /**
     * Class Constructor.
     *
     * @param firstName Customer FirstName
     * @param lastName Customer LastName
     * @param ID Customer ID
     * @param airline airline which has available flights
     */
    public Customer(String firstName, String lastName, int ID, Airline airline){
        this.firstName = firstName;
        this.lastName = lastName;
        this.ID = ID;
        userFlights = new ArrayList<Flight>();
        this.airline = airline;
        tickets = new ArrayList<Ticket>();
    }

    /**
     * Adding flight to user flights, if airline has that flight(it's available)
     *
     * @param flight Flight Object.
     * */
    public void addFlight(Flight flight){
        if(airline.getFlights().contains(flight))
            userFlights.add(flight);

    }

    /**
     * Removing flight from user flights.
     *
     * @param flight Flight object.
     */
    public void removeFlight(Flight flight){
        userFlights.remove(flight);
    }

    /**
     * Getting user flights.
     *
     * @return ArrayList of userFlights.
     */
    public ArrayList<Flight> getUserFlights() {
        return userFlights;
    }

    /**
     * Adding ticket after customer added flight to userFlights.
     *
     * @param flight Flight object
     * @param chairNumber ChairNumber in airplane(If it's a freeChair)
     * @param amountOfBsggage how many baggage that customer has.
     * @param foodReserve does customer wants food or not.
     * @return True if process succeed.
     */
    public void addTicket(Flight flight, int chairNumber, int amountOfBsggage, boolean foodReserve){
        if(userFlights.contains(flight)) {
            Ticket ticket = flight.createTicket(chairNumber, amountOfBsggage,foodReserve);
            if(ticket != null)
                tickets.add(ticket);
        }
    }

    /**
     * showing tickets which Customer booked it before.
     *
     * @return tickets as ArrayList
     */
    public ArrayList<Ticket> getTickets() {
        return tickets;
    }
}
